Crate katac

Crate katac 

Structs

Args
Katac is a tool to help you do katas everyday

Enums

Subcommands

Functions

copy_katas
copies katas from the katas_dir to a new day in days_dir
init_from_examples
initializes katas by selecting from example templates
new_kata
creates a new kata in the kata_dir folder or the given path
random_katas
returns a vector of random katas from the katas.toml file or the katas folder
run_katas
runs the katas in the current day
upgrade_katac
upgrades katac to the latest version from GitHub releases