Structs
- Args
- Katac is a tool to help you do katas everyday
Enums
Functions
- copy_
katas - copies katas from the katas_dir to a new day in days_dir
- init_
from_ examples - initializes katas by selecting from example templates
- new_
kata - creates a new kata in the kata_dir folder or the given path
- random_
katas - returns a vector of random katas from the katas.toml file or the katas folder
- run_
katas - runs the katas in the current day
- upgrade_
katac - upgrades katac to the latest version from GitHub releases